Learn R Programming

ipw (version 1.3.0)

healthdat: IQ, Income and Health

Description

A simulated dataset containing measurements of IQ, monthly income, and health scores for 1000 individuals.

Usage

data(healthdat)

Arguments

Format

A data frame with 1000 rows, with each row corresponding to a separate individual. The following 4 variables are included:

id

Individual ID.

iq

IQ score.

income

Gross monthly income (EUR).

health

Health score (0-100).

Author

Willem M. van der Wal willem@vanderwalresearch.com, Ronald B. Geskus rgeskus@oucru.org

Details

In these simulated data, IQ acts as a confounder for the causal effect of income on health. This dataset is primarily used to illustrate point-treatment inverse probability weighting.

References

Van der Wal W.M. & Geskus R.B. (2011). ipw: An R Package for Inverse Probability Weighting. Journal of Statistical Software, 43(13), 1-23. tools:::Rd_expr_doi("10.18637/jss.v043.i13")

See Also

basdat, haartdat, ipwplot, ipwpoint, ipwtm, timedat, tstartfun

Examples

Run this code
# For an example of how to use this data with ipwpoint, see:
# ?ipwpoint

Run the code above in your browser using DataLab